# Steering Committee

This document lists the members of the Organization's Steering Committee. Voting members may be added once approved by the Steering Committee as described in the [charter](./CHARTER.md). By adding your name to this list you are agreeing to abide by all Organization polices, including the [charter](./CHARTER.md), the [code of conduct](./CODE_OF_CONDUCT.md), the [trademark policy](./TRADEMARKS.md), and the [antitrust policy](./ANTITRUST.md). If you are serving on the Steering Committee because of your affiliation with another organization (designated below), you represent that you have authority to bind that organization to these policies.

| **NAME** | **Handle** | **Affiliated Organization** |
| --- | --- | --- |
| Huigang Chen | @huigangchen | Meta |
| Totte Harinen | @t-tte | AirBnB |
| Jeong-Yoon Lee | @jeongyoonlee | Uber |
| Zhenyu Zhao | @zhenyuz0500 | Tencent |

---
Adapted from [MVG-0.1-beta](https://github.com/github/MVG/tree/v0.1-beta).
Made with love by GitHub. Licensed under the [CC-BY 4.0 License](https://creativecommons.org/licenses/by-sa/4.0/).
